bayespy.nodes.GaussianGammaISO.lower_bound_contribution
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaISO.lower_bound_contribution